//
//  ViewController.m
//  YouriOSApp
//

#import <LaunchKeyManager/LKAuthenticationManager.h>
#import "ViewController.h"
#import "ProtectedViewController.h"

@interface ViewController ()

@end

@implementation ViewController

@synthesize usernameTextField, loginWithLaunchKeyButton, waitIndicator;

#define kOFFSET_FOR_KEYBOARD 170.0

- (void)viewDidLoad {
    [super viewDidLoad];
    
    [self registerForKeyboardNotifications];
    usernameTextField.delegate = self;
    
}

- (IBAction)loginWithLaunchKeyButtonTouched:(id)sender {

    [usernameTextField resignFirstResponder];
    BOOL transactional = NO;
    
    [loginWithLaunchKeyButton setEnabled:NO];
    [waitIndicator startAnimating];
    
    [[LKAuthenticationManager sharedClient] authorize:usernameTextField.text isTransactional:transactional withSuccess:^(NSString *userHash, NSString *authRequest, NSString *pins, NSString *deviceId) {
        [waitIndicator stopAnimating];
        [loginWithLaunchKeyButton setEnabled:YES];
        
        //
        // Remember to save the authRequest as you will use is later to reference this LaunchKey session
        //
        
        ProtectedViewController *protect = [[ProtectedViewController alloc] initWithNibName:@"ProtectedViewController" bundle:nil];
        protect.authRequest = authRequest;
        [[self navigationController] pushViewController:protect animated:YES];
        
    } withFailure:^(NSString *errorMessage, NSString *errorCode) {

        [waitIndicator stopAnimating];
        [loginWithLaunchKeyButton setEnabled:YES];
        
        NSLog(@"%@: %@", errorCode, errorMessage);
    }];
}

-(void)registerForKeyboardNotifications {
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardWillShow)
                                                 name:UIKeyboardWillShowNotification
                                               object:nil];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(keyboardWillHide)
                                                 name:UIKeyboardWillHideNotification
                                               object:nil];
}

-(void)dealloc {
    [[NSNotificationCenter defaultCenter] removeObject:self];
}

-(void)keyboardWillShow {
    if (self.view.frame.origin.y >= 0) {
        [self setViewMovedUp:YES];
    }
}

-(void)keyboardWillHide {
    if (self.view.frame.origin.y >= 0) {
        [self setViewMovedUp:YES];
    }
    else if (self.view.frame.origin.y < 0) {
        [self setViewMovedUp:NO];
    }
}

-(void)textFieldDidBeginEditing:(UITextField *)sender {
    if  (self.view.frame.origin.y >= 0) {
        [self setViewMovedUp:YES];
    }
}

- (BOOL)textFieldShouldReturn:(UITextField *)textField {
    
    [self loginWithLaunchKeyButtonTouched:nil];
    return NO;
}

-(void)setViewMovedUp:(BOOL)movedUp {
    [UIView beginAnimations:nil context:NULL];
    [UIView setAnimationDuration:0.3];
    
    CGRect rect = self.view.frame;
    if (movedUp) {
        rect.origin.y -= kOFFSET_FOR_KEYBOARD;
        rect.size.height += kOFFSET_FOR_KEYBOARD;
    }
    else {
        rect.origin.y += kOFFSET_FOR_KEYBOARD;
        rect.size.height -= kOFFSET_FOR_KEYBOARD;
    }
    self.view.frame = rect;
    
    [UIView commitAnimations];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}


@end
